==> custom_pages-v1.12.9.zip: custom_pages/messages/da/base.php <==
<?php

return [
    'Advanced' => 'Advanced',
    'Always' => 'Altid',
    'Back' => 'Tilbage',
    'Back to dashboard' => 'Tilbage til dashboard',
    'Back to overview' => 'Tilbage til oversigten',
    'Configuration' => 'Konfiguration',
    'Content' => 'Indhold',
    'Create' => 'Opret',
    'Custom' => 'Tilpasset',
    'Custom Pages' => 'Tilpassede Sider',
    'Dashboard' => 'Dashboard',
    'Default' => 'Standard',
    'Delete' => 'Slet',
    'Edit' => 'Rediger',
    'File' => 'Fil',
    'General' => 'Generelt',
    'ID' => 'ID',
    'Insert' => 'Indsæt',
    'Link' => 'Link',
    'MarkDown' => 'MarkDown',
    'Menu settings' => 'Menuindstillinger',
    'Navigation' => 'Navigation',
    'Overview' => 'Oversigt',
    'Public' => 'Offentlig',
    'Reset' => 'Nulstil',
    'Settings' => 'Indstillinger',
    'Snippet' => 'Uddrag',
    'Sort Order' => 'Sorteringsrækkefølge',
    'Source' => 'Kilde',
    'Space' => 'Rum',
    'Spaces' => 'Rum',
    'Stream' => 'Stream',
    'Submit' => 'Indsend',
    'Template' => 'Skabelon',
    'Title' => 'Titel',
    'Top Navigation' => 'Top Navigation',
    'Topics' => 'Emner',
    'Type' => 'Type',
    'User Account Menu (Settings)' => 'Bruger Profil menu (Indstillinger)',
    'Visibility' => 'Synlighed',
    'Without adding to navigation (Direct link)' => 'Uden at tilføje til navigation (Direkte link)',
    '<strong>Add</strong> {templateName} item' => '',
    '<strong>Custom</strong> Pages' => '',
    '<strong>Edit</strong> snippet' => '',
    'Add' => '',
    'Add a file icon before the title' => '',
    'Additional IFrame Attributes' => '',
    'Adds plain HTML content to your site.' => '',
    'Administrative Users' => '',
    'Allows the user to manage custom pages.' => '',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => '',
    'Allows you to add content in MarkDown syntax.' => '',
    'Alternate text' => '',
    'Always make a backup of your view files outside of your production environment!' => '',
    'An empty allowed template selection will allow all container templates for this container.' => '',
    'Authors' => '',
    'Back to space' => '',
    'Can manage custom pages' => '',
    'Cannot delete!' => '',
    'Category' => '',
    'Container' => '',
    'Content filters' => '',
    'Css Class' => '',
    'Custom pages' => '',
    'Default Content' => '',
    'Deleted.' => '',
    'Edit Page' => '',
    'Empty' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'Footer menu' => '',
    'Global Page' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Html' => '',
    'Icon' => '',
    'Iframe' => '',
    'Import' => '',
    'Invalid request data!' => '',
    'Invalid template selection!' => '',
    'Invalid type selection' => '',
    'Invalid view file selection!' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Non-Logged-In Users' => '',
    'On this page you can configure general settings of your custom pages.' => '',
    'PHP' => '',
    'Page' => '',
    'Page Content' => '',
    'Pages' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => '',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => '',
    'Show additional file information (size)' => '',
    'Snippets' => '',
    'Space Members only' => '',
    'Space Navigation' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Start Page' => '',
    'Stream options' => '',
    'Style' => '',
    'Style Class' => '',
    'Target Url' => '',
    'Template Layout' => '',
    'Templates' => '',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => '',
    'This container does not allow any further items!' => '',
    'Upload image' => '',
    'Usage' => '',
    'Will embed the result of a given url as an iframe element.' => '',
    'Will redirect requests to a given (relative or absolute) url.' => '',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => '',
    'Wrap this HTML page with white panel' => '',
    'You are not allowed to delete default content!' => '',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/da/base.php <==
<?php

return [
    'Advanced' => 'Advanced',
    'Always' => 'Altid',
    'Back' => 'Tilbage',
    'Back to dashboard' => 'Tilbage til dashboard',
    'Back to overview' => 'Tilbage til oversigten',
    'Configuration' => 'Konfiguration',
    'Content' => 'Indhold',
    'Create' => 'Opret',
    'Custom' => 'Tilpasset',
    'Custom Pages' => 'Tilpassede Sider',
    'Dashboard' => 'Dashboard',
    'Default' => 'Standard',
    'Delete' => 'Slet',
    'Edit' => 'Rediger',
    'File' => 'Fil',
    'General' => 'Generelt',
    'ID' => 'ID',
    'Insert' => 'Indsæt',
    'Link' => 'Link',
    'MarkDown' => 'MarkDown',
    'Menu settings' => 'Menuindstillinger',
    'Navigation' => 'Navigation',
    'Overview' => 'Oversigt',
    'Public' => 'Offentlig',
    'Reset' => 'Nulstil',
    'Settings' => 'Indstillinger',
    'Snippet' => 'Uddrag',
    'Sort Order' => 'Sorteringsrækkefølge',
    'Source' => 'Kilde',
    'Space' => 'Rum',
    'Spaces' => 'Rum',
    'Stream' => 'Stream',
    'Submit' => 'Indsend',
    'Template' => 'Skabelon',
    'Title' => 'Titel',
    'Top Navigation' => 'Top Navigation',
    'Topics' => 'Emner',
    'Type' => 'Type',
    'User Account Menu (Settings)' => 'Bruger Profil menu (Indstillinger)',
    'Visibility' => 'Synlighed',
    'Without adding to navigation (Direct link)' => 'Uden at tilføje til navigation (Direkte link)',
    '<strong>Add</strong> {templateName} item' => '',
    '<strong>Custom</strong> Pages' => '',
    '<strong>Edit</strong> snippet' => '',
    'Activities' => '',
    'Activity' => '',
    'Activity content ID' => '',
    'Add' => '',
    'Add a file icon before the title' => '',
    'Additional IFrame Attributes' => '',
    'Adds plain HTML content to your site.' => '',
    'Administrative Users' => '',
    'Allows the user to manage custom pages.' => '',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => '',
    'Allows you to add content in MarkDown syntax.' => '',
    'Alternate text' => '',
    'Always make a backup of your view files outside of your production environment!' => '',
    'An empty allowed template selection will allow all container templates for this container.' => '',
    'Authors' => '',
    'Back to space' => '',
    'By creation date' => '',
    'By last update' => '',
    'Can manage custom pages' => '',
    'Cannot delete!' => '',
    'Category' => '',
    'Container' => '',
    'Content filters' => '',
    'Css Class' => '',
    'Custom pages' => '',
    'Default Content' => '',
    'Deleted.' => '',
    'Determine which Spaces should be taken into account.' => '',
    'Edit Page' => '',
    'Empty' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'Footer menu' => '',
    'Global Page' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Html' => '',
    'Icon' => '',
    'Iframe' => '',
    'Import' => '',
    'Include all Spaces except selected' => '',
    'Include selected Spaces only' => '',
    'Invalid request data!' => '',
    'Invalid template selection!' => '',
    'Invalid type selection' => '',
    'Invalid view file selection!' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Non-Logged-In Users' => '',
    'On this page you can configure general settings of your custom pages.' => '',
    'PHP' => '',
    'Page' => '',
    'Page Content' => '',
    'Pages' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => '',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => '',
    'Show additional file information (size)' => '',
    'Snippets' => '',
    'Sorting' => '',
    'Space Members only' => '',
    'Space Navigation' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Space selection' => '',
    'Start Page' => '',
    'Stream options' => '',
    'Style' => '',
    'Style Class' => '',
    'Target Url' => '',
    'Template Layout' => '',
    'Templates' => '',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => '',
    'This container does not allow any further items!' => '',
    'Upload image' => '',
    'Usage' => '',
    'Will embed the result of a given url as an iframe element.' => '',
    'Will redirect requests to a given (relative or absolute) url.' => '',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => '',
    'Wrap this HTML page with white panel' => '',
    'You are not allowed to delete default content!' => '',
];
